@@ -1,7 +1,7 @@
 #[cfg(test)]
 mod inverse_swap {
     use crypto_market_type::MarketType;
-    use crypto_rest_client::{fetch_l2_snapshot, BinanceInverseRestClient};
+    use crypto_rest_client::{fetch_l2_snapshot, fetch_open_interest, BinanceInverseRestClient};
 
     #[test]
     fn test_agg_trades() {
@@ -16,12 +16,19 @@ mod inverse_swap {
             fetch_l2_snapshot("binance", MarketType::InverseSwap, "BTCUSD_PERP", Some(3)).unwrap();
         assert!(text.starts_with("{"));
     }
+
+    #[test]
+    fn test_open_interest() {
+        let text =
+            fetch_open_interest("binance", MarketType::InverseSwap, Some("BTCUSD_PERP")).unwrap();
+        assert!(text.starts_with("{"));
+    }
 }
 
 #[cfg(test)]
 mod inverse_future {
     use crypto_market_type::MarketType;
-    use crypto_rest_client::{fetch_l2_snapshot, BinanceInverseRestClient};
+    use crypto_rest_client::{fetch_l2_snapshot, fetch_open_interest, BinanceInverseRestClient};
 
     #[test]
     fn test_agg_trades() {
@@ -41,4 +48,11 @@ mod inverse_future {
         .unwrap();
         assert!(text.starts_with("{"));
     }
+
+    #[test]
+    fn test_open_interest() {
+        let text = fetch_open_interest("binance", MarketType::InverseFuture, Some("BTCUSD_211231"))
+            .unwrap();
+        assert!(text.starts_with("{"));
+    }
 }
