@@ -1,7 +1,7 @@
 #[cfg(test)]
 mod linear_swap {
     use crypto_market_type::MarketType;
-    use crypto_rest_client::{fetch_l2_snapshot, BinanceLinearRestClient};
+    use crypto_rest_client::{fetch_l2_snapshot, fetch_open_interest, BinanceLinearRestClient};
 
     #[test]
     fn test_agg_trades() {
@@ -15,12 +15,18 @@ mod linear_swap {
             fetch_l2_snapshot("binance", MarketType::LinearSwap, "BTCUSDT", Some(3)).unwrap();
         assert!(text.starts_with("{"));
     }
+
+    #[test]
+    fn test_open_interest() {
+        let text = fetch_open_interest("binance", MarketType::LinearSwap, Some("BTCUSDT")).unwrap();
+        assert!(text.starts_with("{"));
+    }
 }
 
 #[cfg(test)]
 mod linear_future {
     use crypto_market_type::MarketType;
-    use crypto_rest_client::{fetch_l2_snapshot, BinanceLinearRestClient};
+    use crypto_rest_client::{fetch_l2_snapshot, fetch_open_interest, BinanceLinearRestClient};
 
     #[test]
     fn test_agg_trades() {
@@ -31,7 +37,19 @@ mod linear_future {
 
     #[test]
     fn test_l2_snapshot() {
-        let text = fetch_l2_snapshot("binance", MarketType::LinearSwap, "BTCUSDT_211231", Some(3))
+        let text = fetch_l2_snapshot(
+            "binance",
+            MarketType::LinearFuture,
+            "BTCUSDT_211231",
+            Some(3),
+        )
+        .unwrap();
+        assert!(text.starts_with("{"));
+    }
+
+    #[test]
+    fn test_open_interest() {
+        let text = fetch_open_interest("binance", MarketType::LinearFuture, Some("BTCUSDT_211231"))
             .unwrap();
         assert!(text.starts_with("{"));
     }
