@@ -1,7 +1,7 @@
 use std::collections::HashMap;
 
 use crypto_market_type::MarketType;
-use crypto_rest_client::fetch_l2_snapshot;
+use crypto_rest_client::{fetch_l2_snapshot, fetch_open_interest};
 use serde_json::Value;
 use test_case::test_case;
 
@@ -17,3 +17,12 @@ fn test_l2_snapshot(market_type: MarketType, symbol: &str) {
     assert!(data.get("asks").unwrap().as_array().unwrap().len() > 0);
     assert!(data.get("bids").unwrap().as_array().unwrap().len() > 0);
 }
+
+#[test_case(MarketType::InverseSwap)]
+#[test_case(MarketType::LinearSwap)]
+fn test_open_interest(market_type: MarketType) {
+    let text = fetch_open_interest("bitz", market_type, None).unwrap();
+    let obj = serde_json::from_str::<HashMap<String, Value>>(&text).unwrap();
+    let arr = obj.get("data").unwrap().as_array().unwrap();
+    assert!(!arr.is_empty());
+}
